Learn R Programming

archeofrag (version 1.2.3)

GrandeRivoire1stMeso: Dataset: Refitting relationships between bone and lithic fragments from the Grande Rivoire site, First Mesolithic levels

Description

Grande Rivoire is a Mesolithic rock shelter located in France. This dataset describes the refitting 'connection' relationships between bone and lithic fragments found during excavations of the First Mesolithic levels. Connection relationship refers to physical connection between two fragments that were part of the same object.

The dataset is composed of two tables:

  • grande.rivoire.1m.connection: connection relationships between fragments.

  • grande.rivoire.1m.fragments: information about the fragments.

Usage

data(GrandeRivoire1stMeso)

Arguments

Format

  • grande.rivoire.1m.connection is a 712x2 matrix. Each line describes a connection relationship between two fragments. Their unique identifiers are given in column 'id1' and in column 'id2', respectively.

  • grande.rivoire.1m.fragments is a 1165x5 data frame:

    • id: fragment unique identifier

    • layer: archaeological layer where the fragment was found

    • layer.su: combination of the archaeological layer and sedimentary unit where the fragment was found

    • sector: site sector where the fragment was found

    • type: type of object (bone or lithic)

References

  • Derbord L., A. Angelin. 2025. 'Mesolithic artefact refitting data from La Grande Rivoire (Sassenage, Isère)'. Zenodo. https://doi.org/10.5281/zenodo.15289796

Examples

Run this code
data(GrandeRivoire1stMeso)
head(grande.rivoire.1m.fragments)

Run the code above in your browser using DataLab