View source: R/frag.get.layers.R
| frag.get.layers | R Documentation |
Extracts the subgraph of each selected archaeological spatial unit (stratigraphic layer or any other type of spatial unit).
frag.get.layers(graph, layer.attr, sel.layers)
graph |
An undirected |
layer.attr |
Character. The name of the vertices attribute giving the spatial unit of each fragment. |
sel.layers |
Character. The identifier(s) of the stratigraphic spatial units to retrieve. |
This function is only a convenient function to extract the subgraphs of selected archaeological spatial unit (stratigraphic layer or any other type of spatial unit).
A graph is created for each layer in the vertex attribute given by the layer.attr argument.
A list with a graph for each selected stratigraphic layer.
Sebastien Plutniak <sebastien.plutniak at posteo.net>
g <- frag.simul.process(n.components=20, vertices=50, disturbance = .15)
igraph::V(g)$layers <- c(rep("layer1", 20), rep("layer2", 20), rep("layer3", 10))
frag.get.layers(g, layer.attr="layers", sel.layers=c("layer1", "layer2"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.